@@ -3,7 +3,7 @@ package Params::Validate::PP;
 use strict;
 use warnings;
 
-our $VERSION = '1.21';
+our $VERSION = '1.23';
 
 use Params::Validate::Constants;
 use Scalar::Util 1.10 ();
@@ -667,7 +667,7 @@ sub _validate_one_param {
         allow_extra   => 0,
         on_fail       => sub {
             require Carp;
-            Carp::confess( $_[0] );
+            Carp::croak( $_[0] );
         },
         stack_skip     => 1,
         normalize_keys => undef,
@@ -723,7 +723,7 @@ sub _get_called {
         : ( caller( $options->{stack_skip} + $extra_skip ) )[3]
     );
 
-    $called = 'N/A' unless defined $called;
+    $called = '(unknown)' unless defined $called;
 
     return $called;
 }
